code basically stolen from [https://github.com/matoushybl/corroded-drone](https://github.com/matoushybl/corroded-drone)<br>
I just had to copy/paste it because i had to apply macros (and noticed a few API calls were missing)<br>
<br>
check [example](example/) for some examples